class Constants:
    RESOURCE: str = "resource"
    RESOURCE_PATH: str = "path"
    RESOURCE_SERVICE: str = "service"
    RESOURCE_QUERY_PARAMS: str = "query_params"
    RESOURCE_PATH_PARAMS: str = "path_params"
    ACTION: str = "action"
